/*
 * Copyright (c) 2021 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef UNIT_TESTS_MOCK_AUL_MOCK_H_
#define UNIT_TESTS_MOCK_AUL_MOCK_H_

#include <aul.h>
#include <bundle.h>
#include <bundle_cpp.h>
#include <gmock/gmock.h>

#include "module_mock.h"

class AulMock : public virtual ModuleMock {
 public:
  AulMock() {
    using ::testing::_;
    using ::testing::Return;
    using ::testing::Invoke;

    ON_CALL(*this, aul_app_get_appid_bypid(_, _, _))
        .WillByDefault(Invoke([&](int pid, char *appid, int len) -> int {
          snprintf(appid, len, "test_appid");
          return 0;
        }));
  }

  virtual ~AulMock() {}

  MOCK_METHOD3(aul_app_get_appid_bypid, int (int, char*, int));
  MOCK_METHOD4(aul_app_get_pkgid_bypid_for_uid, int (int, char*, int, uid_t));
};

#endif  // UNIT_TESTS_MOCK_AUL_MOCK_H_

