/*
 * Copyright (c) 2021 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef UNIT_TESTS_MOCK_DBUS_MOCK_H_
#define UNIT_TESTS_MOCK_DBUS_MOCK_H_

#include <gmock/gmock.h>
#include <glib.h>
#include <gio/gio.h>

#include "module_mock.h"

class DbusMock : public virtual ModuleMock {
 public:
  DbusMock() {
    using ::testing::_;
    using ::testing::Return;
    using ::testing::Invoke;

    static int dummy;
    GDBusConnection* conn = (GDBusConnection*)&dummy;

    ON_CALL(*this, g_bus_get_sync(_, _, _))
        .WillByDefault(Return(conn));
  }

  MOCK_METHOD3(g_bus_get_sync, GDBusConnection* (GBusType, GCancellable*,
      GError**));
  MOCK_METHOD8(g_dbus_proxy_new_sync, GDBusProxy* (GDBusConnection*,
      GDBusProxyFlags, GDBusInterfaceInfo*, const gchar*, const gchar*,
      const gchar*, GCancellable*, GError**));
  MOCK_METHOD2(g_dbus_node_info_new_for_xml, GDBusNodeInfo* (const gchar*,
      GError**));
  MOCK_METHOD7(g_bus_own_name_on_connection, guint (GDBusConnection*,
      const gchar*, GBusNameOwnerFlags, GBusNameAcquiredCallback,
      GBusNameLostCallback, gpointer, GDestroyNotify));
  MOCK_METHOD7(g_dbus_connection_register_object, guint (GDBusConnection*,
      const gchar*, GDBusInterfaceInfo*, const GDBusInterfaceVTable*, gpointer,
      GDestroyNotify, GError**));
  MOCK_METHOD2(g_dbus_connection_unregister_object, gboolean (GDBusConnection*,
      guint));
  MOCK_METHOD2(g_dbus_method_invocation_return_value,
      void (GDBusMethodInvocation*, GVariant*));
  MOCK_METHOD1(g_bus_unown_name, void (guint));
  MOCK_METHOD7(g_dbus_connection_emit_signal, gboolean (GDBusConnection*,
      const gchar*, const gchar*, const gchar*, const gchar*, GVariant*,
      GError**));
  MOCK_METHOD3(g_dbus_connection_flush_sync, gboolean (GDBusConnection*,
      GCancellable*, GError**));
  MOCK_METHOD1(g_dbus_node_info_unref, void (GDBusNodeInfo*));
  MOCK_METHOD10(g_dbus_connection_signal_subscribe, guint (GDBusConnection*,
      const gchar*, const gchar*, const gchar*, const gchar*, const gchar*,
      GDBusSignalFlags, GDBusSignalCallback, gpointer, GDestroyNotify));
  MOCK_METHOD7(g_dbus_proxy_call_sync, GVariant* (GDBusProxy*, const gchar*,
      GVariant*, GDBusCallFlags, gint, GCancellable*, GError**));
  MOCK_METHOD8(g_dbus_proxy_call, void (GDBusProxy*, const gchar*, GVariant*,
      GDBusCallFlags, gint, GCancellable*, GAsyncReadyCallback, gpointer));
};

#endif  // UNIT_TESTS_MOCK_DBUS_MOCK_H_

