/*
 * Copyright (c) 2021 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef UNIT_TESTS_MOCK_PKGMGR_INFO_MOCK_H_
#define UNIT_TESTS_MOCK_PKGMGR_INFO_MOCK_H_

#include <gmock/gmock.h>
#include <pkgmgr-info.h>

#include "module_mock.h"

class PkgmgrInfoMock : public virtual ModuleMock {
 public:
  PkgmgrInfoMock() {
    using ::testing::_;
    using ::testing::Return;
    using ::testing::Invoke;
  }

  virtual ~PkgmgrInfoMock() {}

  MOCK_METHOD3(pkgmgrinfo_pkginfo_get_usr_pkginfo,
      int (const char *, uid_t, pkgmgrinfo_pkginfo_h*));
  MOCK_METHOD2(pkgmgrinfo_pkginfo_get_api_version,
      int (pkgmgrinfo_pkginfo_h, char **));
  MOCK_METHOD2(pkgmgrinfo_pkginfo_is_global,
      int (pkgmgrinfo_pkginfo_h, bool *));
  MOCK_METHOD1(pkgmgrinfo_pkginfo_destroy_pkginfo,
      int (pkgmgrinfo_pkginfo_h));
  MOCK_METHOD3(pkgmgrinfo_appinfo_get_usr_appinfo,
      int (const char *, uid_t, pkgmgrinfo_appinfo_h*));
  MOCK_METHOD2(pkgmgrinfo_appinfo_get_pkgid,
      int (pkgmgrinfo_pkginfo_h, char **));
  MOCK_METHOD2(pkgmgrinfo_appinfo_get_component_type,
      int (pkgmgrinfo_appinfo_h, char **));
  MOCK_METHOD1(pkgmgrinfo_appinfo_destroy_appinfo,
      int (pkgmgrinfo_appinfo_h));
};

#endif  // UNIT_TESTS_MOCK_PKGMGR_INFO_MOCK_H_

