/*
 * Copyright (c) 2021 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <gmock/gmock.h>
#include <gtest/gtest.h>
#include <unistd.h>

#include "unittest.h"

#ifdef LOG_INTERNAL
#include <dlog.h>

extern "C" int __dlog_print(log_id_t log_id, int prio, const char *tag, const char *fmt, ...) {
  printf("%s:", tag);
  va_list ap;
  va_start(ap, fmt);
  vprintf(fmt, ap);
  va_end(ap);
  printf("\n");

  return 0;
}
#endif

int main(int argc, char **argv) {
  int ret = 0;
  try {
    ::testing::InitGoogleTest(&argc, argv);
  } catch(...) {
    std::cout << "Exception occured" << std::endl;
    return 1;
  }

  try {
    return RUN_ALL_TESTS();
  } catch(const ::testing::internal::GoogleTestFailureException& e) {
    std::cout << "GoogleTestFailureException occured:" << e.what() << std::endl;
    ret = 1;
  }

  return ret;
}

